How to compile cole

cole Library Reference Manual
Prev |  | Next

# Chapter 2. How to compile cole

The file `INSTALL` in the source code gives detailed instructions on how to configure, compile and install cole.

Briefly, you need to run the GNU standard `configure` script, with the arguments you want. To see the arguments that `configure` accepts, run `./configure --help`. The most usual argument is `--prefix=PREFIX`, which tells configure to install cole in the directory `PREFIX`. After that, you need to run `make` to compile cole, and `make install` to install it.

The `configure` script accepts, besides the standard arguments, the following flags:

`--enable-osf-check`. Turn on short align for OSF compiler. If you have errors while compiling under OSF1, enable this flag.
`--enable-verbose`. Turn on verbose. It is useful if you want to send a bug report. It is useful for cole developers too.
`--enable-debug` Turn on GNU CC debug flags. It is useful for cole developers, so may be you don't want to use it.

A tipical session is shown below.

    $ ls
    cole-2.0.0.tar.gz
    $ gzip -d cole-2.0.0.tar.gz
    $ tar -xf cole-2.0.0.tar
    $ ls
    cole-2.0.0.tar      cole-2.0.0/
    $ cd cole-2.0.0
    $ ./configure --prefix=/opt
    ...
    Configured cole release 2.0.0
    $ make
    ...
    $ make install
    ...
    $ make clean
    ...

When installing, a shell script named `cole-config` will be installed in `PREFIX/bin` if you used the the `--prefix=PREFIX` argument, or in `/usr/local/bin` if you didn't. That directory must be listed in the content of the enviroment variable PATH when configuring another program that uses cole.

If you system support it, will be compiled and installed shared libraries, to minimize size of the executables. By this reason, is important to include the directory `PREFIX/bin` or `/usr/local/bin` (which appropiate) in the file that your system command `ldconfig` reads in order to regenerate the list of shared libraries (in some systems, you can list the directory in the content of the enviroment variable LD_LIBRARY_PATH instead).

Prev | Home | Next
Requirements to compile |  | cole Library